<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>Ellipse</name>
    <message>
        <location filename="../Ellipse.js" line="+85"/>
        <source>Ellipse Tools</source>
        <translatorcomment>--google--
Pokaz menu &quot;Elipsy&quot;</translatorcomment>
        <translation>Narzędzia elipsy</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show ellipse tools</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Pokaz menu &quot;Elipsy&quot;</translatorcomment>
        <translation>Wyświetla narzędzia elipsy</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>&amp;Ellipse</source>
        <translatorcomment>--exact match--
--file: qcad_pl.ts--
&amp;Elipsa
Łuk &amp;elipsoidalny (oś)</translatorcomment>
        <translation>&amp;Elipsa</translation>
    </message>
</context>
</TS>
